==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnWidthChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnWidthDescriptionMetadata } from "./ColumnWidthDescriptionMetadata";
import { GridColumnWidthChangedEventArgsDescription } from "./GridColumnWidthChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnWidthChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnWidthChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnWidthChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnWidthChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnWidthChangedEventArgsDescriptionMetadata.c(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridColumnWidthChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
            ColumnWidthDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("OldWidth", "ExportedType:ColumnWidth");
            a.item("NewWidth", "ExportedType:ColumnWidth");
        }
        static d(a) {
            GridColumnWidthChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridColumnWidthChangedEventArgs", () => new GridColumnWidthChangedEventArgsDescription());
            a.z("GridColumnWidthChangedEventArgs", GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnWidthChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnWidthChangedEventArgsDescriptionMetadata, 'GridColumnWidthChangedEventArgsDescriptionMetadata');
    GridColumnWidthChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnWidthChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnWidthChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnWidthDescriptionMetadata } from "./ColumnWidthDescriptionMetadata";
import { GridColumnWidthChangedEventArgsDescription } from "./GridColumnWidthChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnWidthChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnWidthChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnWidthChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnWidthChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnWidthChangedEventArgsDescriptionMetadata.c(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridColumnWidthChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnWidthChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
            ColumnWidthDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("OldWidth", "ExportedType:ColumnWidth");
            a.item("NewWidth", "ExportedType:ColumnWidth");
        }
        static d(a) {
            GridColumnWidthChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridColumnWidthChangedEventArgs", () => new GridColumnWidthChangedEventArgsDescription());
            a.ab("GridColumnWidthChangedEventArgs", GridColumnWidthChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnWidthChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnWidthChangedEventArgsDescriptionMetadata, 'GridColumnWidthChangedEventArgsDescriptionMetadata');
    GridColumnWidthChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnWidthChangedEventArgsDescriptionMetadata;
})();
